# allocGPU
A small Python package that automatically sets multiple **least-loaded** gpus

# How to use the package
After installing the package by
```shell
    pip install allocGPU
```
Import allocGPU at the beginning of your main `.py` file by
```
    import allocGPU
```

You will receive the following message in your terminal
```shell
    Number of GPUs:
```

You can input the number of gpus and press `Enter` to run the program






